@@ -167,13 +167,14 @@ class PsiStatistics(Statistics):
 
 
 class SimpleStatistics(Statistics):
-    @Inject("environment", "insolation_meter")
+    @Inject("environment", "insolation_meter", "size")
     def __init__(self):
         super(SimpleStatistics, self).__init__()
 
     def update(self, step_count, agents):
-        if step_count % 150 == 0:
-            logger.info(self.environment.grid)
+        f = [(x, y, z) for x in range(self.size) for y in range(self.size) for z in range(self.size) if
+             not self.environment.grid[x][y][z].is_empty()]
+        logger.info("%d " % (len(f)))
 
     def summarize(self, agents):
         logger.debug("done")
